from rich import print, box
from rich.table import Table
from rich.console import Console
from rich.align import Align
from rich import print
from ._adlar_cache import cache
from urllib.parse import quote
from http.client import HTTPSConnection
import json


def req(name):
    conn = HTTPSConnection("www.nisanyanadlar.com")
    conn.request(
        "GET", f"/_next/data/hFuzpyuQYJJeP-e3Q0pgO/isim/{name}.json?name={name}"
    )
    res = conn.getresponse()
    data = res.read()
    return json.loads(data)


class Nisadlar:
    def __init__(self, name, random: bool = False):

        if not name:
            self.name = "nonexistname"
        else:
            self.name = name.capitalize()

        self.data = req(quote(self.name))

        if random:
            self.name = self.data["pageProps"]["randomName"].capitalize()
            self.data = req(quote(self.name))
        elif self.name == "nonexistname":
            exit(1)
        elif self.data["pageProps"]["isUnsuccessful"]:
            print("Not found!")
            exit(1)

        self.rich_output()

    def rich_output(self):
        sex_symbol = {"K": "\u2640", "E": "\u2642"}
        for i in json.loads(self.data["pageProps"]["names"]):
            table = Table(box=box.ROUNDED, show_footer=True, expand=True)
            table.add_column(
                f'{sex_symbol[i["sex"]]} {i["entry"]} [grey42]({i["cumulative"]} kişi)[/]',
                header_style="bold",
                footer=Align(
                    f'sıklık sırası: {i["frequency"]}',
                    vertical="middle",
                    align="center",
                    style="grey42",
                ),
            )
            # cache["nations"] nat_code=yt : cache["languages"] lang_code:t
            table.add_row("[#994E8E]Köken:[/#994E8E]" + "\n" + i["means"] + "\n") if i[
                "means"
            ] else None
            table.add_row((i["note"]) + "\n") if i["note"] else None
            # 0: ulusal t: türkçe alanı
            table.add_row(
                "[#994E8E]Dağılım:[/#994E8E]" + "\n" + i["region"] + "\n"
            ) if i["region"] else None
            table.add_row(
                "[#994E8E]Farklı Yazılışlar:[/#994E8E]"
                + "\n"
                + ", ".join([f'{j["name"]} ({j["count"]})' for j in i["variants"]])
            ) if i["variants"] else None
            table.add_row(
                "[#994E8E]İlgili Adlar:[/#994E8E]" + "\n" + ", ".join(i["relatedNames"])
            ) if i["relatedNames"] else None

            print(table)
        Console().print(
            f"[grey42][link=https://www.nisanyanadlar.com/isim/{quote(self.name)}]nisanyanadlar.com/isim/{self.name}↗[/link]",
            justify="right",
        )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nisanyan_cli']

package_data = \
{'': ['*']}

install_requires = \
['importlib-metadata>=5.2.0,<6.0.0', 'rich>=12.6.0,<13.0.0']

entry_points = \
{'console_scripts': ['nis = nisanyan_cli.__main__:cli']}

setup_kwargs = {
    'name': 'nisanyan-cli',
    'version': '0.4.2',
    'description': 'CLI tool for Turkish etymological dictionary, nisanyansozluk.com (nis <word>)',
    'long_description': '![screenshot](https://user-images.githubusercontent.com/16024979/162843362-4050c114-dc82-49eb-ac43-dd6cef79382a.png)\n\n<div align="center">\n<a href="https://github.com/agmmnn/nisanyan-cli">\n<img alt="GitHub release (latest by date)" src="https://img.shields.io/github/v/release/agmmnn/nisanyan-cli"></a>\n<a href="https://pypi.org/project/nisanyan-cli/">\n<img alt="PyPI" src="https://img.shields.io/pypi/v/nisanyan-cli"></a>\n\nCLI tool for Turkish etymological dictionary, [nisanyansozluk.com](https://www.nisanyansozluk.com/).\n\n</div>\n\n## Install\n\n```\npip install nisanyan-cli\n```\n\n## Usege\n\n```\n$ nis yakamoz\n```\n\n![nisanyan-cli](https://user-images.githubusercontent.com/16024979/162844886-7831aebc-8efe-4018-9df5-b26babcc1ca3.png)\n\n### Etymology Tree (`--tree`, `-t`):\n\n```\n$ nis çikolata --tree\nçikolata (Günümüz Türkçesi)\n└── cioccolata (İtalyanca): kakao yağı ve şekerle imal edilen yiyecek maddesi.\n    └── chocolate (İspanyolca): ~.\n        └── xocolatl (Aztekçe): kakaodan yapılan içecek.\n            ├── xocolli (Aztekçe): acı.\n            └── atl (Aztekçe): su.\n```\n\n![Etymology Tree](https://user-images.githubusercontent.com/16024979/164780578-0d51d1b1-31b6-48a4-a09e-b42aa6b6c515.png)\n\n### Random Word (`--random`, `-r`):\n\n```\n$ nis -r -t\nmenekşe (Günümüz Türkçesi)\n└── banafşe ‹بنفشه› (Farsça): aynı anlam.\n    └── vanavşag (Orta Farsça 1300—1500): aynı anlam.\n        └── *vana-vaxşa- (Avestaca MÖ.2000): orman otu.\n            └── vaxşaiti, vaxş- (Avestaca MÖ.2000): yetişmek, bitmek (bitki).\n```\n\n### Adlar (`-ad`):\n\n```\n$ nis gökçe -ad\n```\n\n<img src="https://user-images.githubusercontent.com/16024979/208524422-115cf48b-b2db-4e3e-880f-d43784ed48c6.png" alt="NisanyanAdlar" width="540"/>\n\nAlso you can use `--random`, `-r` argument with `-ad` argument: `nis -ad -r`\n\n## Arguments\n\n```\npositional arguments:\n    <word>\n\noptions:\n    -h, --help     show this help message and exit\n    -t, --tree     show result as etymology tree\n    -r, --random   selects a random word and brings the result\n    -p, --plain    plain text output\n    -ad            show result from nisanyanadlar\n    -v, --version  show program\'s version number and exit\n```\n\n## TODO\n\n- [ ] Köken metninin sitedeki gibi görünmesi için Api\'dan dönen sonucun işlenmesi.\n- [ ] Ek açıklama metnindeki kısaltmaların normal hallerine çevrilmesi.\n- [ ] Decode işlemini python koduna uyarlama.[\\*](https://github.com/agmmnn/Radyal-api/blob/master/api/nisanyan-decrypt.js) (crypto-js/aes, crypto-js/enc-utf8)\n\n## Dependencies\n\n- [rich](https://pypi.org/project/rich/)\n',
    'author': 'Gökçe',
    'author_email': 'agmmnn@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/agmmnn/nisanyan-cli',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
